@@ -1126,14 +1126,12 @@ class GradescopeClient:
                 nonlocal concurrent_requests
                 res = self.get_github_projects(page=page, per_page=1)
                 if res:
-                    print(page, num_threads)
                     with numbers_lock:
                         if concurrent_requests < num_threads:
                             concurrent_requests = num_threads
             concurrent_requests = 2
             p.map(conc_check, [(500, 5), (2000, 10), (5000, 25), (10000, 50), (20000, 75), (50000, 100)])
             p.wait_completion_and_destroy()
-        print(concurrent_requests)
         pool = ThreadPool(concurrent_requests)
 
         def search_for_task(pg_id):
